.. _research:

Research and contribution
===============================

Research
---------------

If you are doing research using Strawberry Fields, please cite `our paper <https://quantum-journal.org/papers/q-2019-03-11-129/>`_:

  Nathan Killoran, Josh Izaac, Nicolás Quesada, Ville Bergholm, Matthew Amy, and Christian Weedbrook. "Strawberry Fields: A Software Platform for Photonic Quantum Computing", Quantum, 3, 129 (2019).

We are always open for collaboration, and can be contacted at research@xanadu.ai.

Contribution
-------------

Strawberry Fields is an open-source library, with the up-to-date code available on GitHub:

- **Source Code:** https://github.com/XanaduAI/strawberryfields
- **Issue Tracker:** https://github.com/XanaduAI/strawberryfields/issues

We welcome contributions - simply fork the Strawberry Fields repository, and then make a
`pull request <https://help.github.com/articles/about-pull-requests/>`_ containing your contribution.  All contributers to Strawberry Fields will be listed as authors on the releases.

We also encourage bug reports, suggestions for new features and enhancements, and even links to cool projects or applications built on Strawberry Fields.

Support
--------

If you are having issues, please let us know by posting the issue on our Github issue tracker.

To chat directly with the team designing and building Strawberry Fields, as well as members of our
community - ranging from professors of quantum physics, to students, to those just interested in being a
part of a rapidly growing industry - you can join our `Slack channel <https://u.strawberryfields.ai/slack>`_.

Available channels:

* ``#strawberryfields``: For general discussion regarding Strawberry Fields
* ``#sf_projects``: For discussion of research ideas and projects built on Strawberry Fields
* ``#sf_bugs``: For discussion of any bugs and issues you run into using Strawberry Fields
* ``#sf_interactive``: For discussion relating to the `Strawberry Fields Interactive <https://strawberryfields.ai>`_ web application
* ``#sf_docs``: For discussion of the Strawberry Fields `documentation <https://strawberryfields.readthedocs.io>`_

Sometimes, it might take us a couple of hours to reply - please be patient!
